#line 2 "BsLexerFX.c"

#line 4 "BsLexerFX.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart (FILE *input_file ,yyscan_t yyscanner );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void yypop_buffer_state (yyscan_t yyscanner );

static void yyensure_buffer_stack (yyscan_t yyscanner );
static void yy_load_buffer_state (yyscan_t yyscanner );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len ,yyscan_t yyscanner );

void *yyalloc (yy_size_t ,yyscan_t yyscanner );
void *yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define yywrap(yyscanner) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 171
#define YY_END_OF_BUFFER 172
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[692] =
    {   0,
        1,    1,  172,  170,    1,    1,  170,  170,  170,    2,
        2,  143,  142,  169,  169,  169,  169,  141,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  140,  169,
      169,   97,   98,   99,  169,  169,  169,  169,  169,  169,
      169,  169,    1,    0,    5,    2,  168,    0,    2,    0,
      169,  169,  169,  169,  169,  169,  169,  149,  169,  169,
      169,  169,  169,  169,  107,  169,  169,  169,  169,  169,
      169,  169,  113,  169,  169,  169,  169,  148,  147,  116,
      169,  169,  169,  169,  169,  169,  111,  169,  169,  169,
      169,  169,  169,  169,  169,  169,   87,  169,  169,  169,

      169,  169,  146,  145,  169,  144,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,    2,  168,    4,    3,
      169,  134,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  108,  169,  169,  169,  169,  169,  121,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  153,  115,  169,
      169,  120,  124,  169,  169,  169,  169,  112,  169,  138,
      137,  169,  169,  169,  169,  169,  169,  114,  169,  169,
      125,  169,  169,  169,  169,  169,  169,  152,  169,  151,

      150,  169,  169,  169,  169,  169,  135,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,    0,    4,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,   60,  169,  130,  169,  169,  169,  169,   86,  169,
      109,   75,   59,  169,  169,   54,  169,  169,  169,  117,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  110,  169,  169,   50,  169,  169,  169,
      154,  136,  169,  169,  131,  169,  169,  169,  169,  169,

      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  104,  155,  169,  118,  169,  169,  100,  169,  169,
      169,  169,  169,  169,  169,    6,  169,    0,    4,  169,
      162,  169,   83,  169,  169,   81,   39,  169,  169,  157,
       82,  169,  169,  169,  169,  169,  132,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,   80,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  160,  169,  169,   41,  169,  169,  105,  133,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,   76,  101,   12,

        7,    8,  169,  169,  169,  169,  103,   66,  165,  169,
      169,  169,  158,   46,  169,  169,   57,  169,  169,  169,
      169,  169,  126,  169,  169,  169,  169,  169,   55,  169,
      169,  169,  169,  169,  161,  169,  156,  169,  169,  169,
      169,   95,   94,  169,  169,  169,  106,  169,  163,  169,
      169,  169,  169,  169,  127,  166,  169,  169,  169,  169,
       85,  169,  169,   79,  169,  169,  169,  169,   51,  169,
        9,   10,   11,   13,   14,   15,   16,   17,   18,   19,
       20,   21,  102,  169,  169,  169,  169,  169,  169,   56,
      169,  123,  128,  167,  169,  169,  169,  169,  169,  169,

      122,   49,  169,  164,  169,  169,  169,  169,  169,  169,
      169,  139,  169,  169,  169,  119,  169,  129,  169,  169,
       64,  169,   70,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
       52,   53,  169,   48,  169,   92,  169,  169,  169,  169,
      159,  169,   42,   47,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  169,  169,  169,   61,
       63,   67,  169,  169,   90,   89,   91,  169,  169,  169,
       22,   23,   24,  169,  169,   40,  169,  169,  169,  169,

       44,   27,   28,   29,  169,  169,  169,   84,  169,  169,
      169,  169,   32,  169,  169,   68,  169,   93,  169,   45,
      169,  169,  169,  169,  169,  169,   58,  169,  169,  169,
      169,  169,  169,   88,  169,  169,   96,  169,   69,  169,
      169,   65,   26,   25,  169,  169,  169,  169,  169,  169,
       31,   30,   43,  169,  169,   37,   35,  169,  169,  169,
      169,  169,  169,  169,   33,  169,  169,   38,  169,  169,
       74,  169,  169,  169,  169,   34,  169,  169,  169,   73,
      169,  169,   36,   77,  169,   62,   71,  169,   78,   72,
        0

    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    1,    1,    1,    1,    1,    1,
        1,    1,    5,    1,    6,    7,    8,    9,   10,   11,
       12,   13,   14,   14,   14,   14,   14,    1,    1,    1,
        1,    1,    1,    1,   15,   16,   17,   18,   19,   20,
       21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
       31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
        1,    1,    1,    1,   24,    1,   41,   42,   43,   44,

       45,   46,   47,   48,   49,   24,   50,   51,   52,   53,
       54,   55,   56,   57,   58,   59,   60,   61,   24,   62,
       63,   24,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[64] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    3,    3,
        3,    3,    3,    3,    4,    4,    4,    4,    3,    3,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        4,    4,    4,    4,    3,    3,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5
    } ;

static yyconst flex_int16_t yy_base[697] =
    {   0,
        0,    0,  791,  792,   62,   64,  786,   59,  781,   67,
       75,   75,   77,   78,   79,  757,   60,  105,  727,   55,
        0,  767,   73,  112,   81,   88,   84,  725,  130,  123,
      124,    0,  739,   79,  103,   96,  729,   93,  741,  733,
      723,  721,  157,  774,  792,  179,    0,  185,  193,    0,
        0,  751,  758,  752,  730,  718,  717,    0,  739,  117,
      713,  710,  731,  752,    0,  127,  715,  748,  730,  735,
       36,  710,    0,  738,  711,  708,  717,    0,  742,  737,
      701,  703,  131,  130,  734,  724,  732,  697,  711,  180,
      123,  131,  697,  716,  193,  727,    0,  712,  721,  157,

      694,  697,    0,  726,  710,  201,  704,  685,  711,  719,
      720,  718,  681,  160,  677,  671,   97,  673,  168,  688,
      673,  670,  694,  710,  675,  691,  681,  672,  661,  668,
      667,  663,  657,  674,  654,  672,  209,    0,  205,    0,
      663,    0,  678,  653,  661,  663,  689,  653,  662,  660,
      658,    0,  675,  647,  174,  642,  648,  661,  212,  682,
      637,  636,  653,  667,  641,  640,  643,    0,    0,  637,
      637,  650,    0,  635,  640,  654,  664,    0,  635,    0,
        0,  649,  660,  664,  658,  211,  618,    0,  199,  653,
        0,  642,  646,  632,  614,  617,  610,    0,  643,    0,

      653,  651,  622,  642,  217,  630,    0,  608,  611,  603,
      619,  602,  605,  597,  609,  607,  595,  600,  607,  592,
      631,  619,  589,  618,  597,  604,  590,  589,  584,  600,
      230,  583,  594,  591,  247,  792,  584,  607,  590,  593,
      580,  613,  587,  580,  584,  612,  597,  569,  571,  195,
      564,    0,  591,    0,  222,  601,  594,  572,    0,  570,
        0,    0,    0,  566,  572,    0,  584,  555,  121,    0,
      599,  553,  583,  562,  557,  560,  559,  198,  566,  557,
      579,  578,  577,    0,  568,  549,    0,  543,  554,  583,
        0,    0,  552,  578,    0,  230,  574,  571,  542,  547,

      533,  533,  546,  545,  544,  541,  532,  524,  525,  538,
      536,    0,    0,  535,    0,  528,  520,    0,  520,  531,
      516,  512,  511,  510,  526,    0,  525,  255,  261,  524,
      551,  509,  532,  521,  532,    0,  505,  505,  501,    0,
        0,  507,  502,  499,  505,  541,    0,  534,  538,  530,
      260,  499,  506,  491,  534,  504,  502,    0,  514,  504,
      512,  492,  493,  490,  489,  477,  485,  482,  478,  506,
      508,  499,  515,  486,  481,    0,  512,  471,    0,    0,
      506,  510,  508,  479,  479,  468,  480,  475,  470,  459,
      458,  467,  458,  459,  497,  450,  484,    0,    0,    0,

        0,  267,  271,  274,  277,  466,    0,    0,    0,  451,
      454,  491,    0,    0,  489,  459,    0,  459,  458,  457,
      471,  484,    0,  482,  449,  446,  451,  438,    0,  441,
      436,  462,  446,  437,  472,  441,    0,  428,  428,  426,
      425,    0,    0,  467,  441,  449,    0,  461,    0,  420,
      419,  458,  431,  459,    0,    0,  417,  455,  415,  429,
        0,  419,  453,    0,  412,  422,  425,  405,    0,  423,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  436,  445,  401,  406,  413,  438,    0,
      441,    0,    0,    0,  415,  406,  413,  404,  393,  388,

        0,    0,  406,    0,  404,  403,  393,  401,  400,  395,
      391,    0,  410,  396,  377,    0,  382,    0,  283,  393,
        0,  386,  267,  376,  375,  291,  377,  387,  374,  377,
      376,  383,  377,  382,  366,  365,  366,  368,  378,  362,
        0,    0,  379,    0,  362,    0,  361,  360,  375,  360,
        0,  357,    0,    0,  395,  394,  393,  375,  354,  363,
      352,  361,  348,  358,  358,  384,  383,  382,  364,  353,
      351,  346,  351,  333,  347,  338,  334,  337,  343,    0,
        0,    0,  343,  334,    0,    0,    0,  328,  334,  326,
        0,  356,    0,  366,  322,    0,  289,  265,  331,  333,

        0,    0,  351,    0,  361,  323,  330,    0,  329,  328,
      327,  314,  338,  326,  322,    0,  308,    0,  321,    0,
      332,  345,  315,  321,  304,  316,    0,  300,  313,  324,
      337,  296,  297,    0,  296,  295,    0,  314,    0,  305,
      333,    0,    0,    0,  332,  304,  292,  318,  299,  286,
        0,    0,    0,  310,  300,    0,    0,  283,  288,  289,
      287,  283,  294,  307,  301,  295,  284,    0,  285,  288,
        0,  269,  269,  280,  276,    0,  265,  245,  233,    0,
      198,  188,    0,    0,  189,    0,    0,   87,    0,    0,
      792,  311,  314,  319,  322,   94

    } ;

static yyconst flex_int16_t yy_def[697] =
    {   0,
      691,    1,  691,  691,  691,  691,  692,  691,  691,  691,
      691,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  691,  692,  691,  691,  694,  691,  691,  695,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,

      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  691,  694,  696,  695,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,

      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  691,  691,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,

      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  691,  691,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,

      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,

      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,

      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
        0,  691,  691,  691,  691,  691

    } ;

static yyconst flex_int16_t yy_nxt[856] =
    {   0,
        4,    5,    6,    7,    4,    8,    4,    9,   10,   11,
       11,   11,   11,   11,   12,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
       28,   29,   30,   31,   32,   33,   34,   21,   21,   35,
       36,   21,   37,   21,   21,   38,   21,   21,   21,   21,
       21,   39,   21,   21,   21,   21,   21,   40,   41,   42,
       21,   21,   21,   43,   43,   43,   43,   46,   46,   46,
       46,   46,   46,   48,   74,   49,   49,   49,   49,   49,
       49,   48,   83,   49,   49,   49,   49,   49,   49,   52,
      161,   58,   53,  162,   63,   86,  139,   68,   98,   94,

       75,  123,   54,   64,   50,   59,   87,   84,   76,   95,
      124,   69,   99,   88,   65,   96,   77,   70,   55,   78,
       79,  126,  127,   71,  100,   56,   89,   60,   50,   57,
       61,   66,   72,  131,   90,  125,  690,   67,   80,   62,
      101,  213,   97,  132,  103,  104,  128,  172,  105,   81,
      106,  109,   91,  214,  110,  129,  111,  112,   43,   43,
       92,  148,  107,  113,  118,  114,  173,  115,  119,  183,
      149,   93,  174,  175,  108,  357,  116,  154,  155,  156,
      120,  117,  358,  185,  184,  186,  121,  137,  137,  137,
      137,  137,  137,  139,  139,  139,  139,  139,  139,   48,

      209,   49,   49,   49,   49,   49,   49,  181,  210,  189,
      216,  182,  190,  194,  195,  200,  201,  137,  137,  137,
      137,  137,  137,  235,  236,  249,  254,  281,  250,  217,
      277,  295,  689,  282,  255,  343,  347,  278,  366,  296,
      322,  323,  324,  256,  380,  688,  367,  687,  297,  235,
      236,  328,  328,  348,  344,  329,  329,  329,  329,  329,
      329,  381,  279,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  425,  426,  471,  472,  473,
      236,  474,  475,  476,  477,  478,  479,  480,  481,  482,
      686,  427,  555,  556,  557,  561,  428,  685,  562,  558,

      566,  567,  568,  563,  624,  626,  236,  569,  625,  684,
      627,   44,  683,   44,   44,   44,   51,   51,   51,  138,
      682,  138,  138,  138,  140,  140,  681,  680,  679,  678,
      677,  676,  675,  674,  673,  672,  671,  670,  669,  668,
      667,  666,  665,  664,  663,  662,  661,  660,  659,  658,
      657,  656,  655,  654,  653,  652,  651,  650,  649,  648,
      647,  646,  645,  644,  643,  642,  641,  640,  639,  638,
      637,  636,  635,  634,  633,  632,  631,  630,  629,  628,
      623,  622,  621,  620,  619,  618,  617,  616,  615,  614,
      613,  612,  611,  610,  609,  608,  607,  606,  605,  604,

      603,  602,  601,  600,  599,  598,  597,  596,  595,  594,
      593,  592,  591,  590,  589,  588,  587,  586,  585,  584,
      583,  582,  581,  580,  579,  578,  577,  576,  575,  574,
      573,  572,  571,  570,  565,  564,  560,  559,  554,  553,
      552,  551,  550,  549,  548,  547,  546,  545,  544,  543,
      542,  541,  540,  539,  538,  537,  536,  535,  534,  533,
      532,  531,  530,  529,  528,  527,  526,  525,  524,  523,
      522,  521,  520,  519,  518,  517,  516,  515,  514,  513,
      512,  511,  510,  509,  508,  507,  506,  505,  504,  503,
      502,  501,  500,  499,  498,  497,  496,  495,  494,  493,

      492,  491,  490,  489,  488,  487,  486,  485,  484,  483,
      470,  469,  468,  467,  466,  465,  464,  463,  462,  461,
      460,  459,  458,  457,  456,  455,  454,  453,  452,  451,
      450,  449,  448,  447,  446,  445,  444,  443,  442,  441,
      440,  439,  438,  437,  436,  435,  434,  433,  432,  431,
      430,  429,  424,  423,  422,  421,  420,  419,  418,  417,
      416,  415,  414,  413,  412,  411,  410,  409,  408,  407,
      406,  405,  404,  403,  402,  401,  400,  399,  398,  397,
      396,  395,  394,  393,  392,  391,  390,  389,  388,  387,
      386,  385,  384,  383,  382,  379,  378,  377,  376,  375,

      374,  373,  372,  371,  370,  369,  368,  365,  364,  363,
      362,  361,  360,  359,  356,  355,  354,  353,  352,  351,
      350,  349,  346,  345,  342,  341,  340,  339,  338,  337,
      336,  335,  334,  333,  332,  331,  330,  327,  326,  325,
      321,  320,  319,  318,  317,  316,  315,  314,  313,  312,
      311,  310,  309,  308,  307,  306,  305,  304,  303,  302,
      301,  300,  299,  298,  294,  293,  292,  291,  290,  289,
      288,  287,  286,  285,  284,  283,  280,  276,  275,  274,
      273,  272,  271,  270,  269,  268,  267,  266,  265,  264,
      263,  262,  261,  260,  259,  258,  257,  253,  252,  251,

      248,  247,  246,  245,  244,  243,  242,  241,  240,  239,
      238,  237,  234,  233,  232,  231,  230,  229,  228,  227,
      226,  225,  224,  223,  222,  221,  220,  219,  218,  215,
      212,  211,  208,  207,  206,  205,  204,  203,  202,  199,
      198,  197,  196,  193,  192,  191,  188,  187,  180,  179,
      178,  177,  176,  171,  170,  169,  168,  167,  166,  165,
      164,  163,  160,  159,  158,  157,  153,  152,  151,  150,
      147,  146,  145,  144,  143,  142,  141,   45,  136,  135,
      134,  133,  130,  122,  102,   85,   82,   73,   47,   45,
      691,    3,  691,  691,  691,  691,  691,  691,  691,  691,

      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691
    } ;

static yyconst flex_int16_t yy_chk[856] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    5,    5,    6,    6,    8,    8,    8,
        8,    8,    8,   10,   17,   10,   10,   10,   10,   10,
       10,   11,   20,   11,   11,   11,   11,   11,   11,   12,
       71,   13,   12,   71,   14,   23,  696,   15,   27,   25,

       17,   34,   12,   14,   10,   13,   23,   20,   17,   25,
       34,   15,   27,   23,   14,   26,   17,   15,   12,   18,
       18,   35,   35,   15,   27,   12,   24,   13,   10,   12,
       13,   14,   15,   38,   24,   34,  688,   14,   18,   13,
       27,  117,   26,   38,   29,   29,   36,   83,   29,   18,
       29,   30,   24,  117,   30,   36,   30,   30,   43,   43,
       24,   60,   29,   30,   31,   30,   83,   30,   31,   91,
       60,   24,   84,   84,   29,  269,   30,   66,   66,   66,
       31,   30,  269,   92,   91,   92,   31,   46,   46,   46,
       46,   46,   46,   48,   48,   48,   48,   48,   48,   49,

      114,   49,   49,   49,   49,   49,   49,   90,  114,   95,
      119,   90,   95,  100,  100,  106,  106,  137,  137,  137,
      137,  137,  137,  139,  139,  155,  159,  189,  155,  119,
      186,  205,  685,  189,  159,  250,  255,  186,  278,  205,
      231,  231,  231,  159,  296,  682,  278,  681,  205,  139,
      139,  235,  235,  255,  250,  235,  235,  235,  235,  235,
      235,  296,  186,  328,  328,  328,  328,  328,  328,  329,
      329,  329,  329,  329,  329,  351,  351,  402,  402,  402,
      329,  403,  403,  403,  404,  404,  404,  405,  405,  405,
      679,  351,  519,  519,  519,  523,  351,  678,  523,  519,

      526,  526,  526,  523,  597,  598,  329,  526,  597,  677,
      598,  692,  675,  692,  692,  692,  693,  693,  693,  694,
      674,  694,  694,  694,  695,  695,  673,  672,  670,  669,
      667,  666,  665,  664,  663,  662,  661,  660,  659,  658,
      655,  654,  650,  649,  648,  647,  646,  645,  641,  640,
      638,  636,  635,  633,  632,  631,  630,  629,  628,  626,
      625,  624,  623,  622,  621,  619,  617,  615,  614,  613,
      612,  611,  610,  609,  607,  606,  605,  603,  600,  599,
      595,  594,  592,  590,  589,  588,  584,  583,  579,  578,
      577,  576,  575,  574,  573,  572,  571,  570,  569,  568,

      567,  566,  565,  564,  563,  562,  561,  560,  559,  558,
      557,  556,  555,  552,  550,  549,  548,  547,  545,  543,
      540,  539,  538,  537,  536,  535,  534,  533,  532,  531,
      530,  529,  528,  527,  525,  524,  522,  520,  517,  515,
      514,  513,  511,  510,  509,  508,  507,  506,  505,  503,
      500,  499,  498,  497,  496,  495,  491,  489,  488,  487,
      486,  485,  484,  470,  468,  467,  466,  465,  463,  462,
      460,  459,  458,  457,  454,  453,  452,  451,  450,  448,
      446,  445,  444,  441,  440,  439,  438,  436,  435,  434,
      433,  432,  431,  430,  428,  427,  426,  425,  424,  422,

      421,  420,  419,  418,  416,  415,  412,  411,  410,  406,
      397,  396,  395,  394,  393,  392,  391,  390,  389,  388,
      387,  386,  385,  384,  383,  382,  381,  378,  377,  375,
      374,  373,  372,  371,  370,  369,  368,  367,  366,  365,
      364,  363,  362,  361,  360,  359,  357,  356,  355,  354,
      353,  352,  350,  349,  348,  346,  345,  344,  343,  342,
      339,  338,  337,  335,  334,  333,  332,  331,  330,  327,
      325,  324,  323,  322,  321,  320,  319,  317,  316,  314,
      311,  310,  309,  308,  307,  306,  305,  304,  303,  302,
      301,  300,  299,  298,  297,  294,  293,  290,  289,  288,

      286,  285,  283,  282,  281,  280,  279,  277,  276,  275,
      274,  273,  272,  271,  268,  267,  265,  264,  260,  258,
      257,  256,  253,  251,  249,  248,  247,  246,  245,  244,
      243,  242,  241,  240,  239,  238,  237,  234,  233,  232,
      230,  229,  228,  227,  226,  225,  224,  223,  222,  221,
      220,  219,  218,  217,  216,  215,  214,  213,  212,  211,
      210,  209,  208,  206,  204,  203,  202,  201,  199,  197,
      196,  195,  194,  193,  192,  190,  187,  185,  184,  183,
      182,  179,  177,  176,  175,  174,  172,  171,  170,  167,
      166,  165,  164,  163,  162,  161,  160,  158,  157,  156,

      154,  153,  151,  150,  149,  148,  147,  146,  145,  144,
      143,  141,  136,  135,  134,  133,  132,  131,  130,  129,
      128,  127,  126,  125,  124,  123,  122,  121,  120,  118,
      116,  115,  113,  112,  111,  110,  109,  108,  107,  105,
      104,  102,  101,   99,   98,   96,   94,   93,   89,   88,
       87,   86,   85,   82,   81,   80,   79,   77,   76,   75,
       74,   72,   70,   69,   68,   67,   64,   63,   62,   61,
       59,   57,   56,   55,   54,   53,   52,   44,   42,   41,
       40,   39,   37,   33,   28,   22,   19,   16,    9,    7,
        3,  691,  691,  691,  691,  691,  691,  691,  691,  691,

      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[172] =
    {   0,
1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,     };

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "BsLexerFX.l"
#line 2 "BsLexerFX.l"
#include "BsParserFX.h"

#define YY_USER_ACTION yylloc->first_column = yycolumn + 1; yylloc->first_line = yylineno + 1; yycolumn += (int)yyleng;
#define YY_USER_INIT yylineno = 0; yycolumn = 0;
#define YY_NO_UNISTD_H 1
#line 883 "BsLexerFX.c"

#define INITIAL 0

/*windows compatibility case*/
#include <io.h>
#define isatty _isatty
#define fileno _fileno
    
#define YY_EXTRA_TYPE struct tagParseState *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    yy_size_t yy_n_chars;
    yy_size_t yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (yyscan_t yyscanner );

int yyget_debug (yyscan_t yyscanner );

void yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra (yyscan_t yyscanner );

void yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *yyget_in (yyscan_t yyscanner );

void yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *yyget_out (yyscan_t yyscanner );

void yyset_out  (FILE * out_str ,yyscan_t yyscanner );

yy_size_t yyget_leng (yyscan_t yyscanner );

char *yyget_text (yyscan_t yyscanner );

int yyget_lineno (yyscan_t yyscanner );

void yyset_lineno (int line_number ,yyscan_t yyscanner );

int yyget_column  (yyscan_t yyscanner );

void yyset_column (int column_no ,yyscan_t yyscanner );

YYSTYPE * yyget_lval (yyscan_t yyscanner );

void yyset_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

       YYLTYPE *yyget_lloc (yyscan_t yyscanner );
    
        void yyset_lloc (YYLTYPE * yylloc_param ,yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (yyscan_t yyscanner );
#else
extern int yywrap (yyscan_t yyscanner );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  ,yyscan_t yyscanner);
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param,YYLTYPE * yylloc_param ,yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 20 "BsLexerFX.l"


#line 1126 "BsLexerFX.c"

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		yy_load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 692 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 691 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			yy_size_t yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 22 "BsLexerFX.l"
{ /* Skip blank */ }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 23 "BsLexerFX.l"
{ yylval->intValue = atoi(yytext); return TOKEN_INTEGER; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 24 "BsLexerFX.l"
{ yylval->intValue = (int)strtol(yytext, 0, 0); return TOKEN_INTEGER; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 25 "BsLexerFX.l"
{ yylval->floatValue = (float)atof(yytext); return TOKEN_FLOAT; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 26 "BsLexerFX.l"
{ yylval->strValue = mmalloc_strdup(yyextra->memContext, yytext); return TOKEN_STRING; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 27 "BsLexerFX.l"
{ yylval->intValue = 1; return TOKEN_BOOLEAN; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 28 "BsLexerFX.l"
{ yylval->intValue = 0; return TOKEN_BOOLEAN; }
	YY_BREAK
/* Value types */
case 8:
YY_RULE_SETUP
#line 32 "BsLexerFX.l"
{ yylval->intValue = PT_Float; return TOKEN_FLOATTYPE; } 
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 33 "BsLexerFX.l"
{ yylval->intValue = PT_Float2; return TOKEN_FLOAT2TYPE; } 
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 34 "BsLexerFX.l"
{ yylval->intValue = PT_Float3; return TOKEN_FLOAT3TYPE; } 
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 35 "BsLexerFX.l"
{ yylval->intValue = PT_Float4; return TOKEN_FLOAT4TYPE; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 36 "BsLexerFX.l"
{ yylval->intValue = PT_Color; return TOKEN_COLORTYPE; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 38 "BsLexerFX.l"
{ yylval->intValue = PT_Mat2x2; return TOKEN_MAT2x2TYPE; } 
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 39 "BsLexerFX.l"
{ yylval->intValue = PT_Mat2x3; return TOKEN_MAT2x3TYPE; } 
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 40 "BsLexerFX.l"
{ yylval->intValue = PT_Mat2x4; return TOKEN_MAT2x4TYPE; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 42 "BsLexerFX.l"
{ yylval->intValue = PT_Mat3x2; return TOKEN_MAT3x2TYPE; } 
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 43 "BsLexerFX.l"
{ yylval->intValue = PT_Mat3x3; return TOKEN_MAT3x3TYPE; } 
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 44 "BsLexerFX.l"
{ yylval->intValue = PT_Mat3x4; return TOKEN_MAT3x4TYPE; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 46 "BsLexerFX.l"
{ yylval->intValue = PT_Mat4x2; return TOKEN_MAT4x2TYPE; } 
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 47 "BsLexerFX.l"
{ yylval->intValue = PT_Mat4x3; return TOKEN_MAT4x3TYPE; } 
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 48 "BsLexerFX.l"
{ yylval->intValue = PT_Mat4x4; return TOKEN_MAT4x4TYPE; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 50 "BsLexerFX.l"
{ yylval->intValue = PT_Sampler1D; return TOKEN_SAMPLER1D; } 
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 51 "BsLexerFX.l"
{ yylval->intValue = PT_Sampler2D; return TOKEN_SAMPLER2D; } 
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 52 "BsLexerFX.l"
{ yylval->intValue = PT_Sampler3D; return TOKEN_SAMPLER3D; } 
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 53 "BsLexerFX.l"
{ yylval->intValue = PT_SamplerCUBE; return TOKEN_SAMPLERCUBE; } 
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 54 "BsLexerFX.l"
{ yylval->intValue = PT_Sampler2DMS; return TOKEN_SAMPLER2DMS; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 56 "BsLexerFX.l"
{ yylval->intValue = PT_Texture1D; return TOKEN_TEXTURE1D; } 
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 57 "BsLexerFX.l"
{ yylval->intValue = PT_Texture2D; return TOKEN_TEXTURE2D; } 
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 58 "BsLexerFX.l"
{ yylval->intValue = PT_Texture3D; return TOKEN_TEXTURE3D; } 
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 59 "BsLexerFX.l"
{ yylval->intValue = PT_TextureCUBE; return TOKEN_TEXTURECUBE; } 
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 60 "BsLexerFX.l"
{ yylval->intValue = PT_Texture2DMS; return TOKEN_TEXTURE2DMS; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 62 "BsLexerFX.l"
{ yylval->intValue = PT_ByteBuffer; return TOKEN_BYTEBUFFER; } 
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 63 "BsLexerFX.l"
{ yylval->intValue = PT_StructBuffer; return TOKEN_STRUCTBUFFER; } 
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 65 "BsLexerFX.l"
{ yylval->intValue = PT_TypedBufferRW; return TOKEN_RWTYPEDBUFFER; } 
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 66 "BsLexerFX.l"
{ yylval->intValue = PT_ByteBufferRW; return TOKEN_RWBYTEBUFFER; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 67 "BsLexerFX.l"
{ yylval->intValue = PT_StructBufferRW; return TOKEN_RWSTRUCTBUFFER; } 
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 68 "BsLexerFX.l"
{ yylval->intValue = PT_AppendBuffer; return TOKEN_RWAPPENDBUFFER; } 
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 69 "BsLexerFX.l"
{ yylval->intValue = PT_ConsumeBuffer; return TOKEN_RWCONSUMEBUFFER; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 71 "BsLexerFX.l"
{ return TOKEN_PARAMSBLOCK; }
	YY_BREAK
/* Shader keywords */
case 40:
YY_RULE_SETUP
#line 74 "BsLexerFX.l"
{ return TOKEN_SEPARABLE; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 75 "BsLexerFX.l"
{ return TOKEN_QUEUE; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 76 "BsLexerFX.l"
{ return TOKEN_PRIORITY; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 77 "BsLexerFX.l"
{ return TOKEN_TRANSPARENT; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 78 "BsLexerFX.l"
{ return TOKEN_TECHNIQUE; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 79 "BsLexerFX.l"
{ return TOKEN_PARAMETERS; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 80 "BsLexerFX.l"
{ return TOKEN_BLOCKS; }
	YY_BREAK
/* Technique keywords */
case 47:
YY_RULE_SETUP
#line 83 "BsLexerFX.l"
{ return TOKEN_RENDERER; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 84 "BsLexerFX.l"
{ return TOKEN_LANGUAGE; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 85 "BsLexerFX.l"
{ return TOKEN_INCLUDE; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 86 "BsLexerFX.l"
{ return TOKEN_PASS; }
	YY_BREAK
/* Pass keywords */
case 51:
YY_RULE_SETUP
#line 89 "BsLexerFX.l"
{ return TOKEN_VERTEX; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 90 "BsLexerFX.l"
{ return TOKEN_FRAGMENT; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 91 "BsLexerFX.l"
{ return TOKEN_GEOMETRY; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 92 "BsLexerFX.l"
{ return TOKEN_HULL; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 93 "BsLexerFX.l"
{ return TOKEN_DOMAIN; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 94 "BsLexerFX.l"
{ return TOKEN_COMPUTE; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 95 "BsLexerFX.l"
{ return TOKEN_COMMON; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 96 "BsLexerFX.l"
{ return TOKEN_STENCILREF; }
	YY_BREAK
/* Rasterizer state keywords */
case 59:
YY_RULE_SETUP
#line 99 "BsLexerFX.l"
{ return TOKEN_FILLMODE; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 100 "BsLexerFX.l"
{ return TOKEN_CULLMODE; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 101 "BsLexerFX.l"
{ return TOKEN_DEPTHBIAS; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 102 "BsLexerFX.l"
{ return TOKEN_SDEPTHBIAS; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 103 "BsLexerFX.l"
{ return TOKEN_DEPTHCLIP; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 104 "BsLexerFX.l"
{ return TOKEN_SCISSOR; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 105 "BsLexerFX.l"
{ return TOKEN_MULTISAMPLE; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 106 "BsLexerFX.l"
{ return TOKEN_AALINE; }
	YY_BREAK
/* Depth-stencil state keywords */
case 67:
YY_RULE_SETUP
#line 109 "BsLexerFX.l"
{ return TOKEN_DEPTHREAD; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 110 "BsLexerFX.l"
{ return TOKEN_DEPTHWRITE; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 111 "BsLexerFX.l"
{ return TOKEN_COMPAREFUNC; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 112 "BsLexerFX.l"
{ return TOKEN_STENCIL; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 113 "BsLexerFX.l"
{ return TOKEN_STENCILREADMASK; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 114 "BsLexerFX.l"
{ return TOKEN_STENCILWRITEMASK; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 115 "BsLexerFX.l"
{ return TOKEN_STENCILOPFRONT; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 116 "BsLexerFX.l"
{ return TOKEN_STENCILOPBACK; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 117 "BsLexerFX.l"
{ return TOKEN_FAIL; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 118 "BsLexerFX.l"
{ return TOKEN_ZFAIL; }
	YY_BREAK
/* Blend state keywords */
case 77:
YY_RULE_SETUP
#line 121 "BsLexerFX.l"
{ return TOKEN_ALPHATOCOVERAGE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 122 "BsLexerFX.l"
{ return TOKEN_INDEPENDANTBLEND; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 123 "BsLexerFX.l"
{ return TOKEN_TARGET; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 124 "BsLexerFX.l"
{ return TOKEN_INDEX; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 125 "BsLexerFX.l"
{ return TOKEN_BLEND; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 126 "BsLexerFX.l"
{ return TOKEN_COLOR; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 127 "BsLexerFX.l"
{ return TOKEN_ALPHA; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 128 "BsLexerFX.l"
{ return TOKEN_WRITEMASK; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 129 "BsLexerFX.l"
{ return TOKEN_SOURCE; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 130 "BsLexerFX.l"
{ return TOKEN_DEST; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 131 "BsLexerFX.l"
{ return TOKEN_OP; }
	YY_BREAK
/* Sampler state keywords */
case 88:
YY_RULE_SETUP
#line 134 "BsLexerFX.l"
{ return TOKEN_ADDRMODE; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 135 "BsLexerFX.l"
{ return TOKEN_MINFILTER; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 136 "BsLexerFX.l"
{ return TOKEN_MAGFILTER; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 137 "BsLexerFX.l"
{ return TOKEN_MIPFILTER; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 138 "BsLexerFX.l"
{ return TOKEN_MAXANISO; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 139 "BsLexerFX.l"
{ return TOKEN_MIPBIAS; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 140 "BsLexerFX.l"
{ return TOKEN_MIPMIN; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 141 "BsLexerFX.l"
{ return TOKEN_MIPMAX; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 142 "BsLexerFX.l"
{ return TOKEN_BORDERCOLOR; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 143 "BsLexerFX.l"
{ return TOKEN_U; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 144 "BsLexerFX.l"
{ return TOKEN_V; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 145 "BsLexerFX.l"
{ return TOKEN_W; }
	YY_BREAK
/* Qualifiers */
case 100:
YY_RULE_SETUP
#line 148 "BsLexerFX.l"
{ return TOKEN_AUTO; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 149 "BsLexerFX.l"
{ return TOKEN_ALIAS; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 150 "BsLexerFX.l"
{ return TOKEN_SHARED; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 151 "BsLexerFX.l"
{ return TOKEN_USAGE; }
	YY_BREAK
/* State values */
case 104:
YY_RULE_SETUP
#line 154 "BsLexerFX.l"
{ yylval->intValue = FMV_Wire; return TOKEN_FILLMODEVALUE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 155 "BsLexerFX.l"
{ yylval->intValue = FMV_Solid; return TOKEN_FILLMODEVALUE; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 157 "BsLexerFX.l"
{ yylval->intValue = CMV_None; return TOKEN_CULLMODEVALUE; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 158 "BsLexerFX.l"
{ yylval->intValue = CMV_CW; return TOKEN_CULLMODEVALUE; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 159 "BsLexerFX.l"
{ yylval->intValue = CMV_CCW; return TOKEN_CULLMODEVALUE; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 161 "BsLexerFX.l"
{ yylval->intValue = CFV_Fail; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 162 "BsLexerFX.l"
{ yylval->intValue = CFV_Pass; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 163 "BsLexerFX.l"
{ yylval->intValue = CFV_LT; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 164 "BsLexerFX.l"
{ yylval->intValue = CFV_LTE; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 165 "BsLexerFX.l"
{ yylval->intValue = CFV_EQ; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 166 "BsLexerFX.l"
{ yylval->intValue = CFV_NEQ; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 167 "BsLexerFX.l"
{ yylval->intValue = CFV_GTE; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 168 "BsLexerFX.l"
{ yylval->intValue = CFV_GT; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 170 "BsLexerFX.l"
{ yylval->intValue = OV_Keep; return TOKEN_OPVALUE; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 171 "BsLexerFX.l"
{ yylval->intValue = OV_Zero; return TOKEN_OPVALUE; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 172 "BsLexerFX.l"
{ yylval->intValue = OV_Replace; return TOKEN_OPVALUE; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 173 "BsLexerFX.l"
{ yylval->intValue = OV_Incr; return TOKEN_OPVALUE; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 174 "BsLexerFX.l"
{ yylval->intValue = OV_Decr; return TOKEN_OPVALUE; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 175 "BsLexerFX.l"
{ yylval->intValue = OV_IncrWrap; return TOKEN_OPVALUE; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 176 "BsLexerFX.l"
{ yylval->intValue = OV_DecrWrap; return TOKEN_OPVALUE; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 177 "BsLexerFX.l"
{ yylval->intValue = OV_Invert; return TOKEN_OPVALUE; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 178 "BsLexerFX.l"
{ yylval->intValue = OV_One; return TOKEN_OPVALUE; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 179 "BsLexerFX.l"
{ yylval->intValue = OV_DestColor; return TOKEN_OPVALUE; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 180 "BsLexerFX.l"
{ yylval->intValue = OV_SrcColor; return TOKEN_OPVALUE; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 181 "BsLexerFX.l"
{ yylval->intValue = OV_InvDestColor; return TOKEN_OPVALUE; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 182 "BsLexerFX.l"
{ yylval->intValue = OV_InvSrcColor; return TOKEN_OPVALUE; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 183 "BsLexerFX.l"
{ yylval->intValue = OV_DestAlpha; return TOKEN_OPVALUE; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 184 "BsLexerFX.l"
{ yylval->intValue = OV_SrcAlpha; return TOKEN_OPVALUE; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 185 "BsLexerFX.l"
{ yylval->intValue = OV_InvDestAlpha; return TOKEN_OPVALUE; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 186 "BsLexerFX.l"
{ yylval->intValue = OV_InvSrcAlpha; return TOKEN_OPVALUE; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 188 "BsLexerFX.l"
{ yylval->intValue = BOV_Add; return TOKEN_BLENDOPVALUE; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 189 "BsLexerFX.l"
{ yylval->intValue = BOV_Subtract; return TOKEN_BLENDOPVALUE; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 190 "BsLexerFX.l"
{ yylval->intValue = BOV_RevSubtract; return TOKEN_BLENDOPVALUE; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 191 "BsLexerFX.l"
{ yylval->intValue = BOV_Min; return TOKEN_BLENDOPVALUE; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 192 "BsLexerFX.l"
{ yylval->intValue = BOV_Max; return TOKEN_BLENDOPVALUE; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 194 "BsLexerFX.l"
{ yylval->intValue = 0x0; return TOKEN_COLORMASK; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 195 "BsLexerFX.l"
{ yylval->intValue = 0x1; return TOKEN_COLORMASK; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 196 "BsLexerFX.l"
{ yylval->intValue = 0x2; return TOKEN_COLORMASK; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 197 "BsLexerFX.l"
{ yylval->intValue = 0x4; return TOKEN_COLORMASK; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 198 "BsLexerFX.l"
{ yylval->intValue = 0x8; return TOKEN_COLORMASK; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 199 "BsLexerFX.l"
{ yylval->intValue = 0x3; return TOKEN_COLORMASK; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 200 "BsLexerFX.l"
{ yylval->intValue = 0x5; return TOKEN_COLORMASK; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 201 "BsLexerFX.l"
{ yylval->intValue = 0x9; return TOKEN_COLORMASK; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 202 "BsLexerFX.l"
{ yylval->intValue = 0x6; return TOKEN_COLORMASK; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 203 "BsLexerFX.l"
{ yylval->intValue = 0xA; return TOKEN_COLORMASK; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 204 "BsLexerFX.l"
{ yylval->intValue = 0xC; return TOKEN_COLORMASK; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 205 "BsLexerFX.l"
{ yylval->intValue = 0x7; return TOKEN_COLORMASK; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 206 "BsLexerFX.l"
{ yylval->intValue = 0xB; return TOKEN_COLORMASK; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 207 "BsLexerFX.l"
{ yylval->intValue = 0xD; return TOKEN_COLORMASK; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 208 "BsLexerFX.l"
{ yylval->intValue = 0xE; return TOKEN_COLORMASK; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 209 "BsLexerFX.l"
{ yylval->intValue = 0xF; return TOKEN_COLORMASK; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 211 "BsLexerFX.l"
{ yylval->intValue = AMV_Wrap; return TOKEN_ADDRMODEVALUE; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 212 "BsLexerFX.l"
{ yylval->intValue = AMV_Mirror; return TOKEN_ADDRMODEVALUE; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 213 "BsLexerFX.l"
{ yylval->intValue = AMV_Clamp; return TOKEN_ADDRMODEVALUE; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 214 "BsLexerFX.l"
{ yylval->intValue = AMV_Border; return TOKEN_ADDRMODEVALUE; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 216 "BsLexerFX.l"
{ yylval->intValue = FV_None; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 217 "BsLexerFX.l"
{ yylval->intValue = FV_Point; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 218 "BsLexerFX.l"
{ yylval->intValue = FV_Linear; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 219 "BsLexerFX.l"
{ yylval->intValue = FV_Anisotropic; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 220 "BsLexerFX.l"
{ yylval->intValue = FV_PointCmp; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 221 "BsLexerFX.l"
{ yylval->intValue = FV_LinearCmp; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 222 "BsLexerFX.l"
{ yylval->intValue = FV_AnisotropicCmp; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 224 "BsLexerFX.l"
{ yylval->intValue = BUV_Static; return TOKEN_BUFFERUSAGE; }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 225 "BsLexerFX.l"
{ yylval->intValue = BUV_Dynamic; return TOKEN_BUFFERUSAGE; }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 227 "BsLexerFX.l"
{ }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 228 "BsLexerFX.l"
{ yylval->strValue = mmalloc_strdup(yyextra->memContext, yytext); return TOKEN_IDENTIFIER; }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 229 "BsLexerFX.l"
{ return yytext[0]; }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 230 "BsLexerFX.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 2087 "BsLexerFX.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 692 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 692 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 691);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp , yyscan_t yyscanner)
{
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = yyg->yy_n_chars + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --yylineno;
    }

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yy_size_t offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	if ( c == '\n' )
		   
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf ,yyscanner );

	yyfree((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
yy_size_t yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */

int yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 229 "BsLexerFX.l"
